﻿#region Copyright Syncfusion Inc. 2001 - 2012
// Copyright Syncfusion Inc. 2001 - 2012. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Navigation;
using System.Xml.Linq;
using System.Xml;

using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using System.IO;
using System.Reflection;
using System.Collections;
using Syncfusion.DocIO.Silverlight.Samples;

namespace UpdateFields
{
    public partial class MainPage : UserControl
    {
        List<ItemInfo> IInfo = new List<ItemInfo>();
        List<SystemInfo> SysInfo = new List<SystemInfo>();

        public MainPage()
        {            
            InitializeComponent();
            InitializeSystem();
            InitializeItem();
        }
        private void InitializeItem()
        {
            IInfo.Clear();
            ItemInfo info;
            string id = "1";
            string desc = "Description";
            string model = "New Model";
            string unit = "Unit1";

            info = new ItemInfo(id, desc, model, unit);
            IInfo.Add(info);            
        }

        private void InitializeSystem()
        {
            SysInfo.Clear();
            SystemInfo sysInfo;
            string id = "1";
            string sysName = "New System";

            sysInfo = new SystemInfo(id, sysName);
            SysInfo.Add(sysInfo);
        }
        private void buttonSample_Click(object sender, RoutedEventArgs e)
        {
            Uri uri = new Uri("Resources/Templates/Template.doc", UriKind.Relative);
            Stream stream = ResourceManager.Load(uri);
            WordDocument document = new WordDocument(stream, FormatType.Doc);
            stream.Close();

            MailMergeDataSet dataSet = new MailMergeDataSet();
            dataSet.Add(new MailMergeDataTable("SystemInfo", SysInfo));
            dataSet.Add(new MailMergeDataTable("ItemInfo", IInfo));
            List<DictionaryEntry> commands = new List<DictionaryEntry>();
            DictionaryEntry entry = new DictionaryEntry("SystemInfo", string.Empty);
            commands.Add(entry);

            // To retrive customer details
            entry = new DictionaryEntry("ItemInfo", "ID = %SystemInfo.ID%");
            commands.Add(entry);

            //Executes nested Mail merge using explicit relational data.
            document.MailMerge.ExecuteNestedGroup(dataSet, commands);

            //Save as .doc Word97-2003 format
            if (rdButtonWord97To2003.IsChecked == true)
                document.SaveAsDoc();
            //Save as .docx Word2007 format
            else if (rdButtonWord2007.IsChecked == true)
                document.SaveAsDocx(rdButtonWord2007.Name);
            //Save as .docx Word2010 format
            else if (rdButtonWord2010.IsChecked == true)
                document.SaveAsDocx(rdButtonWord2010.Name);
            //Save as .docx Word2013 format
            else if (rdButtonWord2013.IsChecked == true)
                document.SaveAsDocx(rdButtonWord2013.Name);
        }

        private void templateButton_Click(object sender, RoutedEventArgs e)
        {
            Uri uri = new Uri("Resources/Templates/Template.doc", UriKind.Relative);

            SaveFileDialog sfd = new SaveFileDialog()
            {
                Filter = "Docx files (*.docx)|*.docx",
                DefaultExt = ".docx",
                FilterIndex = 1
            };
            if (sfd.ShowDialog() == true)
            {
                using (Stream stream = sfd.OpenFile())
                {
                    Stream resourceStream = ResourceManager.Load(uri);
                    resourceStream.CopyTo(stream);
                    resourceStream.Dispose();
                }
                MessageBox.Show("Template document has been downloaded successfully", "Essential DocIO", MessageBoxButton.OK);
            }      
        }
    }

    public class SystemInfo
    {
        #region fields
        private string s_Name;
        private string id;

        #endregion fields

        #region Properties
        public string SystemName
        {
            get { return s_Name; }
            set { s_Name = value; }
        }
        public string ID
        {
            get { return id; }
            set { id = value; }
        }     
        #endregion Properties

        #region Constructors
         public SystemInfo(string id, string systemName)
        {
            this.ID = id;
            this.SystemName = systemName;
        }
        #endregion
    }

    public class ItemInfo
    {
        #region fields
        private string description;
        private string model;
        private string unit;
        private string id;

        #endregion fields

        #region Properties
        public string I_Description
        {
            get { return description; }
            set { description = value; }
        }
        public string I_ManufacturerModel
        {
            get { return model; }
            set { model = value; }
        }
        public string I_QtyUnit
        {
            get { return unit; }
            set { unit = value; }
        }

        public string ID
        {
            get { return id; }
            set { id = value; }
        }
        #endregion Properties

        #region Constructors
        public ItemInfo(string id, string desc, string model, string unit)
        {
            this.ID = id;
            this.I_Description = desc;
            this.I_ManufacturerModel = model;
            this.I_QtyUnit = unit;
        }
        #endregion
    }
}
